import Quagga from "@ericblade/quagga2";
var ReaderType;
(function(ReaderType2) {
  ReaderType2["CODE_128"] = "code_128_reader";
  ReaderType2["EAN"] = "ean_reader";
  ReaderType2["EAN_8"] = "ean_8_reader";
  ReaderType2["CODE_39"] = "code_39_reader";
  ReaderType2["CODE_39_VIN"] = "code_39_vin_reader";
  ReaderType2["CODEABAR"] = "codabar_reader";
  ReaderType2["UPC"] = "upc_reader";
  ReaderType2["UPC_E"] = "upc_e_reader";
  ReaderType2["CODE_I2OF5"] = "i2of5_reader";
  ReaderType2["CODE_2OF5"] = "2of5_reader";
  ReaderType2["CODE_93"] = "code_93_reader";
  ReaderType2["CODE_32"] = "code_32_reader";
})(ReaderType || (ReaderType = {}));
class BarcodeScanner {
  autoCss;
  resultImages;
  resultImagesType;
  resultImagesQuality;
  codeValidator;
  drawLocatedStyle;
  drawDetectedStyle;
  drawScanlineStyle;
  ViewportElement;
  isStarted = false;
  isAutoCssApplied = false;
  scanDeferred = void 0;
  quaggaConfig = {
    inputStream: {
      name: "live",
      type: "LiveStream",
      constraints: {
        width: {min: 800, ideal: 1920, max: 1920},
        height: {min: 600, ideal: 1080, max: 1080},
        facingMode: "environment",
        aspectRatio: {min: 1, max: 2}
      }
    },
    numOfWorkers: navigator.hardwareConcurrency,
    locate: true,
    frequency: 10,
    decoder: {
      multiple: false
    },
    locator: {
      halfSample: true,
      patchSize: "medium"
    }
  };
  constructor(barcodeReaderBuilder) {
    Object.assign(this.quaggaConfig.inputStream ?? {}, {
      target: barcodeReaderBuilder.domTarget
    });
    Object.assign(this.quaggaConfig.decoder ?? {}, {
      readers: barcodeReaderBuilder.readerTypes
    });
    this.autoCss = barcodeReaderBuilder.autoCss;
    this.resultImages = barcodeReaderBuilder.resultImages;
    this.resultImagesType = barcodeReaderBuilder.resultImagesType;
    this.resultImagesQuality = barcodeReaderBuilder.resultImagesQuality;
    this.codeValidator = barcodeReaderBuilder.codeValidator;
    this.drawLocatedStyle = barcodeReaderBuilder.drawLocatedStyle;
    this.drawDetectedStyle = barcodeReaderBuilder.drawDetectedStyle;
    this.drawScanlineStyle = barcodeReaderBuilder.drawScanlineStyle;
    try {
      this.attachViewport();
    } catch {
    }
  }
  async start() {
    if (this.isStarted) {
      return;
    }
    this.isStarted = true;
    try {
      if (!this.ViewportElement) {
        this.attachViewport();
      }
      if (!this.ViewportElement) {
        throw new Error("Cannot start with an undefined viewport target");
      }
      if (this.autoCss && !this.isAutoCssApplied) {
        const style = document.createElement("style");
        document.head.appendChild(style);
        if (!style.sheet) {
          throw new Error("Cannot create dynamic CSS stylesheet");
        }
        const selector = `#${this.ViewportElement.id}`;
        style.sheet.insertRule(`${selector} {display: flex}`);
        style.sheet.insertRule(`${selector} canvas, video {width: 100%}`);
        style.sheet.insertRule(`${selector} canvas.drawingBuffer, video.drawingBuffer {margin-left: -100%}`);
        this.isAutoCssApplied = true;
      }
      await Quagga.init(this.quaggaConfig);
      Quagga.onProcessed(this.onQuaggaProcessed.bind(this));
    } catch (err) {
      this.isStarted = false;
      throw err;
    }
  }
  async stop() {
    if (!this.isStarted) {
      return;
    }
    Quagga.offProcessed();
    if (this.scanDeferred) {
      this.scanDeferred.reject(new Error("Scanner received stop command"));
    }
    await Quagga.stop();
    this.isStarted = false;
  }
  hide() {
    if (this.ViewportElement) {
      this.ViewportElement.style.display = "none";
    }
  }
  show() {
    if (this.ViewportElement) {
      this.ViewportElement.style.display = "block";
    }
  }
  async scanCode() {
    if (!this.isStarted) {
      throw new Error("Scanner not started");
    }
    if (this.scanDeferred) {
      throw new Error("Already scanning for code");
    }
    this.resume();
    try {
      return await new Promise((resolve, reject) => this.scanDeferred = {resolve, reject});
    } finally {
      this.scanDeferred = void 0;
      setTimeout(() => {
        if (!this.scanDeferred) {
          this.clearOverlay();
        }
      }, 200);
    }
  }
  attachViewport() {
    const domTarget = this.quaggaConfig.inputStream?.target;
    if (!domTarget) {
      throw new Error("Viewport target is undefined");
    }
    const selector = domTarget instanceof HTMLElement ? "#" + domTarget.id : String(domTarget);
    try {
      const elem = document.querySelector(selector);
      if (!elem || !(elem instanceof HTMLElement)) {
        throw new Error(`Cannot find element at selector: ${selector}`);
      }
      this.ViewportElement = elem;
    } catch (err) {
      throw new Error(`Invalid selector: ${selector}`);
    }
  }
  resume() {
    Quagga.start();
  }
  pause() {
    Quagga.pause();
  }
  getCanvasBlobPromise(canvas, imageType, imageQuality) {
    return new Promise((resolve, reject) => canvas.toBlob((blob) => {
      if (blob) {
        resolve(blob);
      } else {
        reject();
      }
    }, imageType, imageQuality));
  }
  onQuaggaProcessed(result) {
    if (!this.scanDeferred || !result) {
      return;
    }
    this.clearOverlay();
    if (this.drawLocatedStyle) {
      this.drawLocated(result);
    }
    if (result.codeResult && result.codeResult.code && result.codeResult.startInfo.error < 0.12) {
      if (this.codeValidator && !this.codeValidator(result.codeResult.code)) {
        return;
      }
      if (this.drawDetectedStyle) {
        this.drawDetected(result);
      }
      if (this.drawScanlineStyle) {
        this.drawScanline(result);
      }
      const scanResult = {
        code: result.codeResult.code,
        image: this.resultImages ? this.getCanvasBlobPromise(Quagga.canvas.dom.image, this.resultImagesType, this.resultImagesQuality) : void 0,
        overlay: this.resultImages ? this.getCanvasBlobPromise(Quagga.canvas.dom.overlay, "image/png") : void 0
      };
      this.scanDeferred.resolve(scanResult);
      this.pause();
    }
  }
  get overlayContext() {
    return Quagga.canvas.ctx.overlay;
  }
  get overlayCanvas() {
    return Quagga.canvas.dom.overlay;
  }
  clearOverlay() {
    this.overlayContext.clearRect(0, 0, parseInt(this.overlayCanvas.getAttribute("width") ?? "0"), parseInt(this.overlayCanvas.getAttribute("height") ?? "0"));
  }
  drawLocated(result) {
    if (result.boxes && this.drawLocatedStyle) {
      result.boxes.forEach((box) => {
        if (box !== result.box) {
          Quagga.ImageDebug.drawPath(box, {x: 0, y: 1}, this.overlayContext, this.drawLocatedStyle);
        }
      });
    }
  }
  drawDetected(result) {
    if (result.box && this.drawDetectedStyle) {
      Quagga.ImageDebug.drawPath(result.box, {x: 0, y: 1}, this.overlayContext, this.drawDetectedStyle);
    }
  }
  drawScanline(result) {
    if (result.codeResult && result.codeResult.code && this.drawScanlineStyle) {
      Quagga.ImageDebug.drawPath(result.line, {x: "x", y: "y"}, this.overlayContext, this.drawScanlineStyle);
    }
  }
}
export {
  BarcodeScanner,
  ReaderType
};
//# sourceMappingURL=barcode-scanner.js.map
